Before you open a pull-request, please check if a similar issue already exists or has been closed before.

### When you open a pull-request, please be sure to include the following

- [ ] A descriptive title: [xxx] XXXX
- [ ] A detailed description
- [ ] Assign an issue type tag (label):
  - `dataset` (mimic-it download, usage, etc.),
  - `demo` (online demo),
  - `doc` (readme, wiki, paper, video, etc.),
  - `evaluation` (evaluation result, performance of Otter, etc.),
  - `model` (model configuration, components, etc.),
  - `train` (training configuration, process, code, etc.)

Thank you for your contributions!
